Application Realms
==================

.. contents:: :local:

--------------

ApplicationRealm
----------------

* :class:`cfxdb.mrealm.ApplicationRealm`
* :class:`cfxdb.mrealmschema.ApplicationRealms`
* :class:`cfxdb.mrealmschema.IndexApplicationRealmByName`
* :class:`cfxdb.mrealmschema.IndexApplicationRealmByWebCluster`
* :class:`cfxdb.mrealm.ApplicationRealmRoleAssociation`
* :class:`cfxdb.mrealmschema.ApplicationRealmRoleAssociations`

-------

.. autoclass:: cfxdb.mrealm.ApplicationRealm
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealmschema.ApplicationRealms
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealmschema.IndexApplicationRealmByName
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealmschema.IndexApplicationRealmByWebCluster
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealm.ApplicationRealmRoleAssociation
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealmschema.ApplicationRealmRoleAssociations
    :members:
    :show-inheritance:


Principal
---------

* :class:`cfxdb.mrealmschema.Principal`
* :class:`cfxdb.mrealmschema.Principals`
* :class:`cfxdb.mrealmschema.IndexPrincipalByName`

-------

.. autoclass:: cfxdb.mrealmschema.Principal
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealmschema.Principals
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealmschema.IndexPrincipalByName
    :members:
    :show-inheritance:


Credential
----------

* :class:`cfxdb.mrealmschema.Credential`
* :class:`cfxdb.mrealmschema.Credentials`
* :class:`cfxdb.mrealmschema.IndexCredentialsByAuth`
* :class:`cfxdb.mrealmschema.IndexCredentialsByPrincipal`

-------

.. autoclass:: cfxdb.mrealmschema.Credential
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealmschema.Credentials
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealmschema.IndexCredentialsByAuth
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealmschema.IndexCredentialsByPrincipal
    :members:
    :show-inheritance:


Role
----

* :class:`cfxdb.mrealm.Role`
* :class:`cfxdb.mrealmschema.Roles`
* :class:`cfxdb.mrealmschema.IndexRoleByName`

-------

.. autoclass:: cfxdb.mrealm.Role
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealmschema.Roles
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealmschema.IndexRoleByName
    :members:
    :show-inheritance:


Permission
----------

* :class:`cfxdb.mrealm.Permission`
* :class:`cfxdb.mrealmschema.Permissions`
* :class:`cfxdb.mrealmschema.IndexPermissionByUri`

-------

.. autoclass:: cfxdb.mrealm.Permission
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealmschema.Permissions
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealmschema.IndexPermissionByUri
    :members:
    :show-inheritance:
